@@ -7,8 +7,13 @@ class SheetsPlus(Sheets):
     Inherits Gsheets library
 
     """
+    def __getitem__(self):
+        '''
 
-    def plot(self, x, y, df):
+        '''
+        super().__init__()
+
+    def plot(self, x, y):
         """Plots graph between x and y axis.
 
         Args:
@@ -16,7 +21,9 @@ class SheetsPlus(Sheets):
             y (str): Y-axis for the graph
             df (pandas.DataFrame) : Pandas DataFrame containing sheets data
         """
-        x = df[x].sort_values(ascending=True)
-        y = df[y].sort_values(ascending=True)
-        plt.scatter(x, y)
+        values = self._items[0]._values
+
+        # x = df[x].sort_values(ascending=True)
+        # y = df[y].sort_values(ascending=True)
+        # plt.scatter(x, y)
         plt.savefig("temp.jpg")
